@@ -1,7 +1,8 @@
 package SelfLoader;
 use 5.008;
 use strict;
-our $VERSION = "1.16";
+use IO::Handle;
+our $VERSION = "1.19";
 
 # The following bit of eval-magic is necessary to make this work on
 # perls < 5.009005.
@@ -99,9 +100,10 @@ sub _load_stubs {
     # Protect: fork() shares the file pointer between the parent and the kid
     if(sysseek($fh, tell($fh), 0)) {
       open my $nfh, '<&', $fh or croak "reopen: $!";# dup() the fd
-      close $fh or die "close: $1";                 # autocloses, but be paranoid
+      close $fh or die "close: $!";                 # autocloses, but be paranoid
       open $fh, '<&', $nfh or croak "reopen2: $!";  # dup() the fd "back"
-      close $nfh or die "close after reopen: $1";   # autocloses, but be paranoid
+      close $nfh or die "close after reopen: $!";   # autocloses, but be paranoid
+      $fh->untaint;
     }
     $Cache{"${currpack}::<DATA"} = 1;   # indicate package is cached
 
@@ -406,8 +408,8 @@ This package has the same copyright and license as the perl core:
     
     You should also have received a copy of the GNU General Public License
     along with this program in the file named "Copying". If not, write to the 
-    Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 
-    02111-1307, USA or visit their web page on the internet at
+    Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
+    MA 02110-1301, USA or visit their web page on the internet at
     http://www.gnu.org/copyleft/gpl.html.
     
     For those of you that choose to use the GNU General Public License,
